注： 1、标黄为终态，推送该状态后续不会在继续推送内容 2、付费用户以此状态为准，不使用 state | 物流状态 | | 状态码 | 业务字段说明 | | :--- | --- | :--- | :--- | | 已揽收 | 已揽收 | 1 | 快递员已上门揽收快递 | | | 待揽件 | 10 | 快递员未去取件 | | 在途中 | 到达派件城市 | 201 | 快件到达派件城市 | | | 派件中 | 202 | 快件由派件员进行派件 | | | 已放入快递柜或驿站 | 211 | 快件放入快递柜或者驿站 | | | 到达转运中心 | 204 | 快件在转运中心做到件扫描 | | | 到达派件网点 | 205 | 快件在派件网点做到件扫描 | | | 寄件网点发件 | 206 | 快件在寄件网点做发件扫描 | | | 在途 | 2 | 货物在途中运输 | | 已签收 | 正常签收 | 301 | 快件由收件人签收 | | | 异常后最终签收 | 302 | 快件途中出现异常后，正常签收 | | | 代收签收 | 304 | 快件由非收件人本人代签 | | | 快递柜或驿站签收 | 311 | 快件由快递柜或驿站签收 | | | 已签收 | 3 | 快件被签收 | | 转寄 | 转寄 | 5 | 快递被转寄到新地址 | | 问题件 | 发货无信息 | 401 | 运单轨迹中没有任何描述，或者直接为空， 或者描述上发货无信息 | | | 超时未签收 | 402 | 运单最后一条轨迹(含有派件动作的描述)，该条轨迹产生时间，距当前查询时间，超时36 小时或轨迹中描述超时未签收 | | | 超时未更新 | 403 | 运单轨迹最后一条时间距当前时间超过5天 | | | 拒收（退件） | 404 | 客户拒收产生退件 | | | 派件异常 | 405 | 派件异常 | | | 退货签收 | 406 | 退件后由寄件人进行签收 | | | 退货未签收 | 407 | 退件后由寄件人未签收 | | | 快递柜或驿站超时未取 | 412 | 放入快递柜后超过18个小时没有取件 | | | 单号已拦截 | 413 | 快件在途中被快递员拦截 | | | 破损 | 414 | 货物破损 | | | 客户取消发货 | 415 | 客户取消下单 | | | 无法联系 | 416 | 派送中无法联系到收件人 | | | 配送延迟 | 417 | 快递公司配送延迟 | | | 快件取出 | 418 | 快递员把快件从快递柜取出 | | | 重新派送 | 419 | 快递员与客户沟通 重新派送 | | | 收货地址不详细 | 420 | 收货地址不详细 | | | 收件人电话错误 | 421 | 收件人电话错误 | | | 错分件 | 422 | 网点或中心错误分拣 | | | 超区件 | 423 | 派件超出派送范围 | | | 问题件 | 4 | 问题件 | | 清关 | 清关 | 6 | 货物在目的国清关 | | | 待清关 | 601 | 货物在目的国待清关 | | | 清关中 | 602 | 货物在目的国清关 | | | 已清关 | 603 | 货物在目的国已清关 | | | 清关异常 | 604 | 货物在目的国出现清关异常 | | 暂无轨迹信息 | 暂无轨迹信息 | 0 | 货物暂无轨迹信息 |